#!/bin/bash

checkForZimbraCore() {
  if ($(determinePkgManager querystring) zimbra-core >/dev/null 2>&1); then
    echo -e ""
    echo -e "zimbra-core package has been found."
    echo -e ""
  else
    echo -e "zimbra-core package is required and has not been found."
    exit 2
  fi
}

checkUser() {
  local USERID
  USERID="$(id -u)"
  if [[ $USERID -ne 0 ]]; then
    echo "Run as root!"
    exit 1
  fi
}

disclaimer() {
  echo -e ""
  echo -e "This script will install Zextras Theme, onto the running system."
  echo -e ""
  inquire "System will be modified, would you like to proceed?" "Y"
  if [[ $answer == yes ]]; then
    :
  else
    exit 1
  fi
  unset answer
  checkForZimbraCore
}

dockerDisclaimer() {
  echo -e ""
  echo -e "\\t NOTICE \\t"
  echo -e "Using the package inside a Container is not supported."
  echo -e "This release requires systemd to work properly."
  echo -e ""
}

inquire() {
  local PROMPT
  PROMPT="$1"
  local DEFAULT
  DEFAULT="$2"

  shopt -s nocasematch

  if [[ -n $DEFAULT ]]; then
    if [[ $DEFAULT == @(yes|y) ]]; then
      DEFAULT="Y"
    else
      DEFAULT="N"
    fi
  fi

  while :; do
    while read -r -t 0; do read -r; done
    echo ""
    echo -n "$PROMPT [$DEFAULT] "
    read -r answer

    if [[ -z $answer && -n $DEFAULT ]]; then
      answer=$DEFAULT
    fi

    if [[ $answer == @(yes|y) ]]; then
      answer="yes"
      break
    else
      if [[ $answer == @(no|n) ]]; then
        answer="no"
        break
      fi
    fi
    echo "Only a Yes/No answer can be given"
  done
  shopt -u nocasematch
}

installPackage() {
  inquire "Would you like to install Zextras Theme?" "Y"
  if [[ $answer == yes ]]; then

    if [[ "${MYOSDISTRO}" == "ubuntu" ]]; then
      apt install -y "${MYDIR}"/packages/*.deb
    else
      yum install -y "${MYDIR}"/packages/*.rpm
    fi
  else
    echo -e ""
    exit 1
  fi
}
