#!/bin/bash

checkOS() {
  shopt -s nocasematch

  if [[ "${MYOSDISTRO}" == "ubuntu" ]] && [[ ${MYOSVERSION} -lt 16 || ${MYOSVERSION} -gt 20 ]]; then
    echo "This version will only work on a system running Ubuntu 16.04, 18.04 or 20.04."
    exit 1
  fi

  if [[ "${MYOSDISTRO}" == "centos" ]] && [[ ${MYOSVERSION} -lt 6 || ${MYOSVERSION} -gt 8 ]]; then
    echo "This version will only work on a system running CentOS 6, 7 or 8."
    exit 1
  fi

  if [[ "${MYOSDISTRO}" == "rhel" ]] && [[ ${MYOSVERSION} -lt 6 || ${MYOSVERSION} -gt 8 ]]; then
    echo "This version will only work on a system running Red Hat Enterprise Linux 6, 7 or 8."
    exit 1
  fi

  if [[ "${MYOSDISTRO}" == "ol" ]] && [[ ${MYOSVERSION} -lt 6 || ${MYOSVERSION} -gt 8 ]]; then
    echo "This version will only work on a system running Oracle Linux 6, 7 or 8."
    exit 1
  fi

  shopt -u nocasematch
}

determineOSdistribution() {
  if [[ -f /etc/os-release ]]; then
    . /etc/os-release
  elif [[ -f /etc/redhat-release ]]; then
    local ID="centos"
  fi
  shopt -s nocasematch
  if [[ "${ID}" == "Ubuntu" ]]; then
    case "${VERSION_ID}" in
      20.04) local VERSION_CODENAME="focal" ;;
      18.04) local VERSION_CODENAME="bionic" ;;
      16.04) local VERSION_CODENAME="xenial" ;;
      *)
        echo -e "Sorry, the version of Ubuntu you "
        echo -e "are trying to use it's not supported."
        exit 225
        ;;
    esac
  elif [[ "${ID}" == "CentOS" ]]; then
    case "${VERSION_ID}" in
      8) local VERSION_CODENAME="8" ;;
      7) local VERSION_CODENAME="7" ;;
      6) local VERSION_CODENAME="6" ;;
      *)
        local VERSION_CODENAME
        VERSION_CODENAME="$(grep -oP '\d(?=\.\d+)' /etc/redhat-release)"
        ;;
    esac
  elif [[ "${ID}" == "ol" ]]; then
    case "${VERSION_ID%.*}" in
      8) local VERSION_CODENAME="8" ;;
      7) local VERSION_CODENAME="7" ;;
      6) local VERSION_CODENAME="6" ;;
      *)
        local VERSION_CODENAME
        VERSION_CODENAME="$(grep -oP '\d(?=\.\d+)' /etc/redhat-release)"
        ;;
    esac
  fi
  shopt -u nocasematch
  case "$1" in
    1) echo -e "${ID}" ;;
    2) echo -e "${VERSION_CODENAME}" ;;
    3) echo -e "${VERSION_ID/.*/}" ;;
    "all") echo "${ID} ${VERSION_CODENAME} ${VERSION_ID/.*/}" ;;
    *)
      echo -e "Please provide a valid input!"
      ;;
  esac
  unset "ID"
}

determinePkgManager() {
  local PKGQUERY
  local PKGQUERYARG
  local PKGMGR
  local PKGMGRARG
  shopt -s nocasematch
  if [[ "${MYOSDISTRO}" == "ubuntu" ]]; then
    PKGQUERY="dpkg"
    PKGQUERYARG="-s"
    PKGMGR="apt"
    PKGMGRARG="install"
    PKGMGRUPDATE="apt update"
  elif [[ "${MYOSDISTRO}" == "centos" || "${MYOSDISTRO}" == "ol" || "${MYOSDISTRO}" == "rhel" ]]; then
    PKGQUERY="yum"
    PKGQUERYARG="list -q installed"
    PKGMGR="yum"
    PKGMGRARG="install"
    PKGMGRUPDATE="true"
  fi
  shopt -u nocasematch
  case "$1" in
    "querystring")
      echo "$PKGQUERY $PKGQUERYARG"
      ;;
    "installstring")
      echo "$PKGMGR $PKGMGRARG"
      ;;
    "pkgmgr")
      echo "$PKGMGR"
      ;;
    "update")
      echo "$PKGMGRUPDATE"
      ;;
    *) ;;
  esac
}
